@@ -475,11 +475,15 @@ def in_gevent():
 has_tty = lambda: sys.stdin.isatty() and sys.stdout.isatty()
 
 
-def confirm(msg):
+def confirm(msg, dflt='n'):
     if not has_tty():
         raise Exception('Require confirmation for: %s' % msg)
+
     print(msg)
-    r = input('Confirmed [y|N]? ')
+    opts = ['y|N'] if dflt.lower() == 'n' else 'Y|n'
+    r = input(f'Confirmed [{opts}]? ')
+    if not r:
+        r = dflt
     if r.lower() != 'y':
         from devapp.app import app
 
@@ -979,13 +983,17 @@ def check_start_env(req_env):
     return 'Passed requirements check'
 
 
-def read_file(fn, dflt=None, bytes=-1, strip_comments=False):
+def read_file(fn, dflt=None, mkfile=False, bytes=-1, strip_comments=False):
     """
     API function.
     read a file - return a default if it does not exist"""
     if not exists(fn):
         if dflt is not None:
+            if mkfile:
+                write_file(fn, dflt, mkdir=1)
             return dflt
+        if mkfile:
+            raise Exception(fn, 'Require dflt to make non existing file')
         raise Exception(fn, 'does not exist')
     with open(fn) as fd:
         # no idea why but __etc__hostname always contains a linesep at end
@@ -998,17 +1006,46 @@ def read_file(fn, dflt=None, bytes=-1, strip_comments=False):
         return res
 
 
+def unlink(fn, not_exist_ok=False, log=None, err_hint=None):
+    if os.path.exists(fn) or os.path.islink(fn):  # dangling
+        log('Unlinking', fn=fn) if log else 0
+        try:
+            return os.unlink(fn) or True
+        except Exception as ex:
+            from devapp.app import app
+
+            kw = {'fn': fn, 'problem': str(ex)}
+            kw.update({'hint': err_hint} if err_hint else {})
+            app.die('Cannot unlink', **kw)
+    if not_exist_ok:
+        return False
+    os.unlink(fn)  # raise original exception (File not found)
+
+
+def get_app(c=[0]):
+    app = c[0]
+    if app:
+        return app
+    from devapp.app import app
+
+    c[0] = app
+    return app
+
+
 def write_file(fn, s, log=0, mkdir=0, chmod=None, mode='w'):
     'API: Write a file. chmod e.g. 0o755 (as octal integer)'
-    from devapp.app import app
 
     fn = os.path.abspath(fn)
 
     if log > 0:
+        app = get_app()
         app.info('Writing file', fn=fn)
 
-    if isinstance(s, (list, tuple)):
+    if isinstance(s, (list, tuple)) and s and isinstance(s[0], str):
         s = '\n'.join(s)
+    elif isinstance(s, (dict, tuple, list)):  # think of bytes, mode wb
+        s = json.dumps(s, default=str)
+
     if log > 1:
         sep = '\n----------------------\n'
         ps = (
@@ -1039,6 +1076,24 @@ def write_file(fn, s, log=0, mkdir=0, chmod=None, mode='w'):
         raise Exception('Could not write file: %s %s' % (fn, e))
 
 
+def sys_args(*args):
+    """sometimes we want sys args already before the flags are parsed - in order to set
+    their defaults, e.g. from a config file"""
+    argv = list(sys.argv[1:])
+    r = [a[2] for a in args]  # the defaults
+    while argv:
+        a = argv.pop(0)
+        i = -1
+        for c in args:
+            i += 1
+            if a.startswith(c[1]) or a.startswith(c[2]):
+                if '=' in a:
+                    r[i] = a.split('=', 1)[1]
+                elif argv:
+                    r[i] = argv.pop(0)
+    return tuple(r)
+
+
 def failsafe(meth, *a, **kw):
     """Spotted log errors at aggressively reconnecting clients, running in greenlets
     in the pytest progs. This allows to wrap these methods.
